BackendSelected class final

每次 NiumaPlayerController.initialize 成功后精确触发一次,告知最终 选中的 backend。

Inheritance

Constructors

BackendSelected(PlayerBackendKind kind, {required bool fromMemory})
const

Properties

fromMemory bool
【已废弃语义】设备记忆已移除,恒为 false;仅为兼容保留, 后续 major 版本删除。
final
hashCode int
The hash code for this object.
no setterinherited
kind PlayerBackendKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited