NiumaWebFullscreenMode enum

当前 web 浏览器的全屏策略——接入方据此分流全屏 UI。

Inheritance
Available extensions

Values

notWeb → const NiumaWebFullscreenMode

非 web 平台(Android / iOS 原生 App)。

nativeVideoElement → const NiumaWebFullscreenMode

iOS Safari 等:只支持 <video> 元素级全屏(进系统原生 player、 不保留 Flutter 控件)。走 NiumaPlayerController.enterNativeFullscreen()

browserElement → const NiumaWebFullscreenMode

Chrome / Firefox / 桌面 Safari 等:支持对画布 Element 全屏,可保留 Flutter 控件。走 requestBrowserFullscreen + 自己的全屏 UI。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NiumaWebFullscreenMode>
A constant List of the values in this enum, in order of their declaration.